Index: content/public/browser/gpu_service_registry.h |
diff --git a/content/public/browser/gpu_service_registry.h b/content/public/browser/gpu_service_registry.h |
index 6f041807ea436fd228a52403192153b580218b81..e1455f3dab4e81d6f283fc907310d0777aaca5bf 100644 |
--- a/content/public/browser/gpu_service_registry.h |
+++ b/content/public/browser/gpu_service_registry.h |
@@ -7,16 +7,17 @@ |
#include "content/common/content_export.h" |
-namespace shell { |
+namespace service_manager { |
class InterfaceProvider; |
} |
namespace content { |
// Get shell::InterfaceProvider that can be used to bind interfaces registered |
// via ContentGpuClient::ExposeInterfacesToBrowser(). |
// This must be called on IO thread. |
-CONTENT_EXPORT shell::InterfaceProvider* GetGpuRemoteInterfaces(); |
+CONTENT_EXPORT service_manager::InterfaceProvider* GetGpuRemoteInterfaces(); |
} // namespace content |
@@ -7,16 +7,17 @@ |
} |
namespace content { |
-// Get shell::InterfaceProvider that can be used to bind interfaces registered |
+// Get service_manager::InterfaceProvider that can be used to bind interfaces |
+// registered |
// via ContentGpuClient::ExposeInterfacesToBrowser(). |
// This must be called on IO thread. |